[SerialICE] r67 - in trunk/SerialICE: . mainboard

svn at coresystems.de svn at coresystems.de
Thu Nov 26 13:10:35 CET 2009


Author: stepan
Date: 2009-11-26 13:10:34 +0100 (Thu, 26 Nov 2009)
New Revision: 67

Modified:
   trunk/SerialICE/mainboard/asus_m2v-mx_se.c
   trunk/SerialICE/mainboard/asus_p2b.c
   trunk/SerialICE/mainboard/dell_s1850.c
   trunk/SerialICE/mainboard/intel_d945gclf.c
   trunk/SerialICE/mainboard/kontron_986lcd-m.c
   trunk/SerialICE/mainboard/msi_ms6178.c
   trunk/SerialICE/mainboard/rca_rm4100.c
   trunk/SerialICE/mainboard/thomson_ip1000.c
   trunk/SerialICE/serialice.c
Log:
Add mainboard name and version info commands
Signed-off-by: Stefan Reinauer <stepan at coresystems.de>



Modified: trunk/SerialICE/mainboard/asus_m2v-mx_se.c
===================================================================
--- trunk/SerialICE/mainboard/asus_m2v-mx_se.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/asus_m2v-mx_se.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -18,6 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
+const char boardname[33]="ASUS M2V-MX SE                  ";
+
 #define SUPERIO_CONFIG_PORT		0x2e
 
 static void superio_init(void)

Modified: trunk/SerialICE/mainboard/asus_p2b.c
===================================================================
--- trunk/SerialICE/mainboard/asus_p2b.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/asus_p2b.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * This is a chipset init file for the ASUS P2B mainboard.
- */
+/* This is a chipset init file for the ASUS P2B mainboard.  */
 
+const char boardname[33]="ASUS P2B                        ";
+
 #define PNP_PORT                  0x3f0
 
 static void superio_init(void)

Modified: trunk/SerialICE/mainboard/dell_s1850.c
===================================================================
--- trunk/SerialICE/mainboard/dell_s1850.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/dell_s1850.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * This is an example chipset init file for the Dell S1850
- */
+/* This is a chipset init file for the Dell S1850 */
 
+const char boardname[33]="DELL S1850                      ";
+
 /* Hardware specific functions */
 static void mainboard_set_ich5(void)
 {

Modified: trunk/SerialICE/mainboard/intel_d945gclf.c
===================================================================
--- trunk/SerialICE/mainboard/kontron_986lcd-m.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/kontron_986lcd-m.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * This is an example chipset init file for the Kontron 986LCD-M mainboard
- */
+/* This is a chipset init file for the Kontron 986LCD-M mainboard */
 
+const char boardname[33]="Kontron 986LCD-M                ";
+
 /* Hardware specific functions */
 
 #define RCBA	0xfed1c000

Modified: trunk/SerialICE/mainboard/msi_ms6178.c
===================================================================
--- trunk/SerialICE/mainboard/msi_ms6178.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/msi_ms6178.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -18,6 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
+const char boardname[33]="MSI MS6178                      ";
+
 #define PMBASE			0x40
 #define COM_DEC			0xe0
 #define LPC_EN			0xe6

Modified: trunk/SerialICE/mainboard/rca_rm4100.c
===================================================================
--- trunk/SerialICE/mainboard/rca_rm4100.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/rca_rm4100.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -17,9 +17,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * This is an example chipset init file for the RCA RM4100 mainboard
- */
+/* This is a chipset init file for the RCA RM4100 mainboard */
+ 
+const char boardname[33]="RCA RM4100                      ";
 
 /* Hardware specific functions */
 

Modified: trunk/SerialICE/mainboard/thomson_ip1000.c
===================================================================
--- trunk/SerialICE/mainboard/thomson_ip1000.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/thomson_ip1000.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * This is an example chipset init file for the THOMSON IP1000 mainboard
- */
+/* This is a chipset init file for the THOMSON IP1000 mainboard */
 
+const char boardname[33]="THOMSON IP1000                  ";
+
 /* Hardware specific functions */
 
 #define PMBASE 0x400

Modified: trunk/SerialICE/serialice.c
===================================================================
--- trunk/SerialICE/serialice.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/serialice.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -186,13 +186,24 @@
 	sio_put32(reg32);
 }
 
+static void serialice_mainboard(void)
+{
+	/* must be defined in mainboard/<boardname>.c */
+	sio_putstring(boardname);
+}
+
+static void serialice_version(void)
+{
+	sio_putstring("\nSerialICE v" VERSION " (" __DATE__ ")\n");
+}
+
 int main(void)
 {
 	chipset_init();
 
 	sio_init();
 
-	sio_putstring("\nSerialICE v" VERSION " (" __DATE__ ")\n");
+	serialice_version();
 
 	while(1) {
 		u16 c;
@@ -227,6 +238,11 @@
 		case (('c' << 8)|'i'): // Read CPUID *ci
 			serialice_cpuinfo();
 			break;
+		case (('m' << 8)|'b'): // Read mainboard type *mb
+			serialice_mainboard();
+			break;
+		case (('v' << 8)|'i'): // Read version info *vi
+			serialice_mainboard();
 		default:
 			sio_putstring("ERROR\n");
 			break;




More information about the SerialICE mailing list
--- trunk/SerialICE/mainboard/intel_d945gclf.c	2009-11-21 15:31:20 UTC (rev 66)
+++ trunk/SerialICE/mainboard/intel_d945gclf.c	2009-11-26 12:10:34 UTC (rev 67)
@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
 /*
  * This is an example chipset init file for the Kontron 986LCD-M mainboard
  */
 
+const char boardname[33]="Intel D945GCLF                  ";
+
 /* Hardware specific functions */
 
 #define RCBA	0xfed1c000
@@ -17,10 +17,10 @@
  */
 
-/*
- * This is an example chipset init file for the Kontron 986LCD-M mainboard
- */
+/* This is a chipset init file for the Intel D945GCLF mainboard */
 

Modified: trunk/SerialICE/mainboard/kontron_986lcd-m.c
===================================================================